# Soham_thesis

Thesis files are in tex/

To run figure making scripts, install this as a pip package with 'pip install -e <<path/to/soham_thesis>>'.

For windows machines do 'pip install <<path/to/soham_thesis>> --user'

Other python dependencies (will be auto-installed by pip):
Matplotlib
Seaborn
